@@ -1,23 +1,8 @@
-/***************************************************************************
- *   KSystemLog, a system log viewer tool                                  *
- *   Copyright (C) 2007 by Nicolas Ternisien                               *
- *   nicolas.ternisien@gmail.com                                           *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the                         *
- *   Free Software Foundation, Inc.,                                       *
- *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.          *
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2007 Nicolas Ternisien <nicolas.ternisien@gmail.com>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "logLevelFileList.h"
 
@@ -35,7 +20,7 @@
 #include "defaults.h"
 
 #include "globals.h"
-#include "logging.h"
+#include "ksystemlog_debug.h"
 
 #include "logLevel.h"
 #include "logLevelSelectionDialog.h"
@@ -45,7 +30,7 @@ int LogLevelFileList::LogLevelRole = 33;
 LogLevelFileList::LogLevelFileList(QWidget *parent, const QString &description)
     : FileList(parent, description)
 {
-    logDebug() << "Initializing specific file list...";
+    qCDebug(KSYSTEMLOG) << "Initializing specific file list...";
 
     changeItem = new QPushButton(i18n("&Change Status..."));
     changeItem->setToolTip(i18n("Change the level of the current file(s)"));
@@ -71,7 +56,7 @@ LogLevelFileList::LogLevelFileList(QWidget *parent, const QString &description)
 
     updateSpecificButtons();
 
-    logDebug() << "Specific file list initialized";
+    qCDebug(KSYSTEMLOG) << "Specific file list initialized";
 }
 
 LogLevelFileList::~LogLevelFileList()
@@ -112,12 +97,13 @@ void LogLevelFileList::updateSpecificButtons()
 
 void LogLevelFileList::changeItemType()
 {
-    logDebug() << "Changing item type...";
+    qCDebug(KSYSTEMLOG) << "Changing item type...";
 
     LogLevelSelectionDialog logLevelSelectionDialog(this);
     QListWidget *logLevels = logLevelSelectionDialog.logLevels();
 
-    foreach (LogLevel *level, Globals::instance().logLevels()) {
+    const auto logLevelsItems{Globals::instance().logLevels()};
+    for (LogLevel *level : logLevelsItems) {
         logLevels->addItem(new QListWidgetItem(level->icon(), level->name()));
     }
 
@@ -161,7 +147,7 @@ void LogLevelFileList::addPaths(const QStringList &stringList, const QList<int>
 {
     // A little security test
     if (stringList.size() != valueList.size()) {
-        logDebug() << i18n("The two arrays size are different, skipping the reading of generic paths.");
+        qCDebug(KSYSTEMLOG) << i18n("The two arrays size are different, skipping the reading of generic paths.");
         return;
     }
 
@@ -189,3 +175,5 @@ void LogLevelFileList::addPaths(const QStringList &stringList, const QList<int>
 
     Q_EMIT fileListChanged();
 }
+
+#include "moc_logLevelFileList.cpp"
